==> mosaicml-cli-0.3.8.tar.gz: mosaicml-cli-0.3.8/mcli/api/inference_deployments/api_get_inference_deployments.py <==
"""get__inference_deployments SDK for MAPI"""
from __future__ import annotations

from concurrent.futures import Future
from datetime import datetime
from typing import List, Optional, Union, overload

from typing_extensions import Literal

from mcli.api.engine.engine import get_return_response, run_plural_mapi_request
from mcli.api.model.inference_deployment import InferenceDeployment
from mcli.config import MCLIConfig
from mcli.models.mcli_cluster import Cluster
from mcli.serverside.clusters.gpu_type import GPUType

__all__ = ['get_inference_deployments']

QUERY_FUNCTION = 'getInferenceDeployments'
VARIABLE_DATA_NAME = 'getInferenceDeploymentsData'
QUERY = f"""
query GetInferenceDeployments(${VARIABLE_DATA_NAME}: GetInferenceDeploymentsInput!) {{
  {QUERY_FUNCTION}({VARIABLE_DATA_NAME}: ${VARIABLE_DATA_NAME}) {{
    id
    name
    inferenceDeploymentInput
    originalInferenceDeploymentInput
    status
    createdAt
    updatedAt
    deletedAt
    publicDNS
  }}
}}"""


@overload
def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = 10,
    future: Literal[False] = False,
) -> List[InferenceDeployment]:
    ...


@overload
def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = None,
    future: Literal[True] = True,
) -> Future[List[InferenceDeployment]]:
    ...


def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = 10,
    future: bool = False,
):
    """List inference deployments that have been launched in the MosaicML platform
    The returned list will contain all of the details stored about the requested deployments.
    Arguments:
        deployments: List of inference deployments on which to get information
        clusters: List of clusters to filter inference deployments. This can be a list of str or
            :type Cluster: objects. Only deployments submitted to these clusters will be
            returned.
        before: Only inference deployments created strictly before this time will be returned. This
            can be a str in ISO 8601 format(e.g 2023-03-31T12:23:04.34+05:30)
            or a datetime object.
        after: Only inference deployments created at or after this time will be returned. This can
            be a str in ISO 8601 format(e.g 2023-03-31T12:23:04.34+05:30)
            or a datetime object.
        gpu_types: List of gpu types to filter inference deployments. This can be a list of str or
            :type GPUType: enums. Only deployments scheduled on these GPUs will be returned.
        gpu_nums: List of gpu counts to filter inference deployments. Only deployments scheduled on this number
            of GPUs will be returned.
        statuses: List of inference deployment statuses to filter deployments. This can be a list of str.
            Only deployments currently in these phases will be returned.
        timeout: Time, in seconds, in which the call should complete. If the call
            takes too long, a TimeoutError will be raised. If ``future`` is ``True``, this
            value will be ignored.
        future: Return the output as a :type concurrent.futures.Future:. If True, the
            call to `get_inference_deployments` will return immediately and the request will be
            processed in the background. This takes precedence over the ``timeout``
            argument. To get the list of deployments, use ``return_value.result()``
            with an optional ``timeout`` argument.
    Raises:
        MAPIException: If connecting to MAPI, raised when a MAPI communication error occurs
    """

    filters = {}
    if deployments:
        filters['name'] = {'in': [r.name if isinstance(r, InferenceDeployment) else r for r in deployments]}
    if before or after:
        date_filters = {}
        if before:
            date_filters['lt'] = before.astimezone().isoformat() if isinstance(before, datetime) else before
        if after:
            date_filters['gte'] = after.astimezone().isoformat() if isinstance(after, datetime) else after
        filters['createdAt'] = date_filters
    if statuses:
        filters['status'] = {'in': statuses}
    if clusters:
        filters['cluster'] = {'in': [c.name if isinstance(c, Cluster) else c for c in clusters]}
    if gpu_types:
        filters['gpuType'] = {'in': [gt.value if isinstance(gt, GPUType) else gt for gt in gpu_types]}
    if gpu_nums:
        filters['gpuNum'] = {'in': gpu_nums}

    variables = {
        VARIABLE_DATA_NAME: {
            'filters': filters,
            'includeDeleted': False,
        },
    }

    cfg = MCLIConfig.load_config(safe=True)
    if cfg.user_id:
        variables[VARIABLE_DATA_NAME]['entity'] = {'userIds': [cfg.user_id]}

    response = run_plural_mapi_request(
        query=QUERY,
        query_function=QUERY_FUNCTION,
        return_model_type=InferenceDeployment,
        variables=variables,
    )

    return get_return_response(response, future=future, timeout=timeout)

==> mosaicml-cli-0.4.0a2.tar.gz: mosaicml-cli-0.4.0a2/mcli/api/inference_deployments/api_get_inference_deployments.py <==
"""get__inference_deployments SDK for MAPI"""
from __future__ import annotations

from concurrent.futures import Future
from datetime import datetime
from typing import List, Optional, Union, overload

from typing_extensions import Literal

from mcli.api.engine.engine import get_return_response, run_plural_mapi_request
from mcli.api.model.inference_deployment import InferenceDeployment
from mcli.config import MCLIConfig
from mcli.models.gpu_type import GPUType
from mcli.models.mcli_cluster import Cluster

__all__ = ['get_inference_deployments']

QUERY_FUNCTION = 'getInferenceDeployments'
VARIABLE_DATA_NAME = 'getInferenceDeploymentsData'
QUERY = f"""
query GetInferenceDeployments(${VARIABLE_DATA_NAME}: GetInferenceDeploymentsInput!) {{
  {QUERY_FUNCTION}({VARIABLE_DATA_NAME}: ${VARIABLE_DATA_NAME}) {{
    id
    name
    inferenceDeploymentInput
    originalInferenceDeploymentInput
    status
    createdAt
    updatedAt
    deletedAt
    publicDNS
    createdByEmail
  }}
}}"""


@overload
def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = 10,
    future: Literal[False] = False,
) -> List[InferenceDeployment]:
    ...


@overload
def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = None,
    future: Literal[True] = True,
) -> Future[List[InferenceDeployment]]:
    ...


def get_inference_deployments(
    deployments: Optional[Union[List[str], List[InferenceDeployment]]] = None,
    clusters: Optional[Union[List[str], List[Cluster]]] = None,
    before: Optional[Union[str, datetime]] = None,
    after: Optional[Union[str, datetime]] = None,
    gpu_types: Optional[Union[List[str], List[GPUType]]] = None,
    gpu_nums: Optional[List[int]] = None,
    statuses: Optional[List[str]] = None,
    timeout: Optional[float] = 10,
    future: bool = False,
):
    """List inference deployments that have been launched in the MosaicML platform
    The returned list will contain all of the details stored about the requested deployments.
    Arguments:
        deployments: List of inference deployments on which to get information
        clusters: List of clusters to filter inference deployments. This can be a list of str or
            :type Cluster: objects. Only deployments submitted to these clusters will be
            returned.
        before: Only inference deployments created strictly before this time will be returned. This
            can be a str in ISO 8601 format(e.g 2023-03-31T12:23:04.34+05:30)
            or a datetime object.
        after: Only inference deployments created at or after this time will be returned. This can
            be a str in ISO 8601 format(e.g 2023-03-31T12:23:04.34+05:30)
            or a datetime object.
        gpu_types: List of gpu types to filter inference deployments. This can be a list of str or
            :type GPUType: enums. Only deployments scheduled on these GPUs will be returned.
        gpu_nums: List of gpu counts to filter inference deployments. Only deployments scheduled on this number
            of GPUs will be returned.
        statuses: List of inference deployment statuses to filter deployments. This can be a list of str.
            Only deployments currently in these phases will be returned.
        timeout: Time, in seconds, in which the call should complete. If the call
            takes too long, a TimeoutError will be raised. If ``future`` is ``True``, this
            value will be ignored.
        future: Return the output as a :type concurrent.futures.Future:. If True, the
            call to `get_inference_deployments` will return immediately and the request will be
            processed in the background. This takes precedence over the ``timeout``
            argument. To get the list of deployments, use ``return_value.result()``
            with an optional ``timeout`` argument.
    Raises:
        MAPIException: If connecting to MAPI, raised when a MAPI communication error occurs
    """

    filters = {}
    if deployments:
        filters['name'] = {'in': [r.name if isinstance(r, InferenceDeployment) else r for r in deployments]}
    if before or after:
        date_filters = {}
        if before:
            date_filters['lt'] = before.astimezone().isoformat() if isinstance(before, datetime) else before
        if after:
            date_filters['gte'] = after.astimezone().isoformat() if isinstance(after, datetime) else after
        filters['createdAt'] = date_filters
    if statuses:
        filters['status'] = {'in': statuses}
    if clusters:
        filters['cluster'] = {'in': [c.name if isinstance(c, Cluster) else c for c in clusters]}
    if gpu_types:
        filters['gpuType'] = {'in': [gt.value if isinstance(gt, GPUType) else gt for gt in gpu_types]}
    if gpu_nums:
        filters['gpuNum'] = {'in': gpu_nums}

    variables = {
        VARIABLE_DATA_NAME: {
            'filters': filters,
            'includeDeleted': False,
        },
    }

    cfg = MCLIConfig.load_config(safe=True)
    if cfg.user_id:
        variables[VARIABLE_DATA_NAME]['entity'] = {'userIds': [cfg.user_id]}

    response = run_plural_mapi_request(
        query=QUERY,
        query_function=QUERY_FUNCTION,
        return_model_type=InferenceDeployment,
        variables=variables,
    )

    return get_return_response(response, future=future, timeout=timeout)
